============
Installation
============

At the command line either via easy_install or pip::

    $ easy_install dovpanda
    $ pip install dovpanda

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv dovpanda
    $ pip install dovpanda
